{
  self,
  pkgs,
  ...
}: let
  encryptedUSBData = import "${self}/data/drives/encryptedUSB.nix";
in {
  home.packages = with pkgs; [eza bat ripgrep vault-bin libarchive age];
  programs.zsh = {
    enable = true;
    syntaxHighlighting.enable = true;
    autosuggestion.enable = true;
    oh-my-zsh = {
      enable = true;
      theme = "afowler";
      plugins = [];
    };
    shellAliases = {
      nixdirfmt = "alejandra . && statix fix . && deadnix -e .";
      tar = "bsdtar";
      exa = "eza";
      eza = "eza --time-style long-iso";
      la = "eza -Ga";
      ll = "eza -l";
      lla = "eza -lga";
      ip6 = "ip -6";
      sys = "systemctl";
      sysu = "systemctl --user";
      logu = "journalctl --user";
      log = "journalctl";
      dmesg = "dmesg -HP";
      hg = "history 0 | rg";
      chaos_age = "age -i ${encryptedUSBData.chaosAgePrivateKeyPath}";
      chaos_age_encrypt = "age -a -e -i ${encryptedUSBData.chaosAgePrivateKeyPath}";
      chaos_pub = "cat ${encryptedUSBData.chaosAgePublicKeyPath}";
    };
    envExtra = ''
      export VAULT_ADDR="https://vault.owo.monster"
    '';
  };
  programs.direnv = {
    enable = true;
    enableZshIntegration = true;
  };
}
