{
  self,
  hostPath,
  tree,
  inputs,
  config,
  pkgs,
  ...
}: let
  containerAddresses = import "${hostPath}/data/containerAddresses.nix";
  hostIP = containerAddresses.host;
  containerIP = containerAddresses.containers.quassel;
in {
  containers.quassel = {
    autoStart = true;
    privateNetwork = true;
    hostAddress = hostIP;
    localAddress = containerIP;

    specialArgs = {
      inherit inputs;
      inherit tree;
      inherit self;
      inherit hostPath;
    };

    config = {...}: {
      nixpkgs.pkgs = pkgs;

      imports = with tree;
        [
          presets.nixos.containerBase

          ./secrets.nix
        ]
        ++ (with hosts.hetzner-arm.containers.quassel.profiles; [
          quassel
          restic
        ]);

      networking.firewall.allowedTCPPorts = [4242];

      home-manager.users.root.home.stateVersion = "23.05";
      system.stateVersion = "23.05";
    };
  };

  networking.nat.forwardPorts = [
    {
      sourcePort = 4242;
      destination = "${containerIP}\:4242";
    }
  ];

  networking.firewall.allowedTCPPorts = [4242];
}
